@@ -93,6 +93,10 @@
 /* MPlayer is not yet 'on the bus', so we use a good old named pipe */
 #define MPLAYER_FIFO "/etc/headphoned/mplayer-input"
 
+/* Martin's FM Radio app on the D-Bus */
+#define FMRADIO_SRVC "de.pycage.fmradio"
+#define FMRADIO_PATH "/de/pycage/fmradio"
+#define FMRADIO_INTF "de.pycage.fmradio"
 
 typedef struct {
     DBusConnection* session_bus;
@@ -167,6 +171,18 @@ broadcast_pause_signal(Headphoned* headphoned)
     } else {
         debug_msg("MPlayer not running - not sending pause signal.");
     }
+
+    /* FM Radio */
+    if (dbus_bus_name_has_owner(headphoned->session_bus, FMRADIO_SRVC, NULL)) {
+        debug_msg("Sending pause signal to FM Radio");
+        osso_rpc_run(headphoned->osso,
+                FMRADIO_SRVC,
+                FMRADIO_PATH,
+                FMRADIO_INTF,
+                "stop",
+                NULL,
+                DBUS_TYPE_INVALID);
+    }
 }
 
 /* Handler for messages from "wired" headphones (via sysfs) */
